==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/VaisravanasPagodaItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.danmaku.DanmakuTrajectory;
import cc.thonly.reverie_dreams.danmaku.DanmakuTypes;
import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1796;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3419;

public class VaisravanasPagodaItem extends class_1792 {

    public VaisravanasPagodaItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.field_9236 && world instanceof class_3218 serverWorld) {
            class_1799 itemStack = user.method_5998(hand);
            float pitch = user.method_36455();
            float yaw = user.method_36454();
            for (int i = 0; i < 3; i++) {
                DanmakuEntity entity = DanmakuTrajectory.spawnByItemStack(
                        serverWorld, user, user.method_23317(), user.method_23318(), user.method_23321(),
                        DanmakuTypes.random(DanmakuTypes.LASER),
                        pitch, yaw, 1.6f, 0f, 0.0f, 1.5f
                );
                entity.setOnHitEffect((livingEntity, damage) -> {
                    livingEntity.setFireTicks(20 * 5);
                });
            }
            class_1796 itemCooldownManager = user.method_7357();
            itemCooldownManager.method_62835(itemStack, 20 * 10);
            itemStack.method_61653(1, user);
            world.method_43128(null, user.method_23317(), user.method_23318(), user.method_23321(), SoundEventInit.FIRE, class_3419.field_15254, 1f, 1.0f);

            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/VaisravanasPagodaItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.data.danmaku.DanmakuTrajectory;
import cc.thonly.reverie_dreams.registry.content.danmaku.DanmakuTypes;
import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1796;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3419;

public class VaisravanasPagodaItem extends class_1792 {

    public VaisravanasPagodaItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.field_9236 && world instanceof class_3218 serverWorld) {
            class_1799 itemStack = user.method_5998(hand);
            float pitch = user.method_36455();
            float yaw = user.method_36454();
            for (int i = 0; i < 3; i++) {
                DanmakuEntity entity = DanmakuTrajectory.spawnByItemStack(
                        serverWorld, user, user.method_23317(), user.method_23318(), user.method_23321(),
                        DanmakuTypes.random(DanmakuTypes.LASER),
                        pitch, yaw,
                        0.0f, 1.5f
                );
                entity.setOnHitEffect((livingEntity, damage) -> {
                    livingEntity.setRemainingFireTicks(20 * 5);
                });
            }
            class_1796 itemCooldownManager = user.method_7357();
            itemCooldownManager.method_62835(itemStack, 20 * 10);
            itemStack.method_61653(1, user);
            world.method_43128(null, user.method_23317(), user.method_23318(), user.method_23321(), SoundEventInit.FIRE, class_3419.field_15254, 1f, 1.0f);

            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}
